TestLogEntry<T> class
Constructors
Properties
- endTime → DateTime
-
final
- exception → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- result → T?
-
final
- resultSerializer → String Function(T)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → String?
-
final
- startTime → DateTime
-
final
- status → String
-
final
- testName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCsvRow(
) → String -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
-
toTextBlock(
) → String
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited