TestLogger class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
logFailure({required String testName, DateTime? startTime, required Object exception, required StackTrace stackTrace, String message = 'Test failed.'})
→ void
-
-
logFailureAuto<T>({required String testName, DateTime? startTime, T? result, Object? input, Object? exception, StackTrace? stackTrace})
→ void
-
-
logSuccess<T>({required String testName, DateTime? startTime, required T result, String message = 'Test passed.', String resultSerializer(T)?})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
writeReport()
→ Future<void>
-